/**********************************************************************
 *
 * ResultBox.java -- a list of phrases in the Phind java interface
 *
 * Copyright 1997-2000 Gordon W. Paynter
 * Copyright 2000 The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/

/*********************************************************************

This class is used in the Phind java applet (Phind.java).

A result item object holds the data describing a single line returned from
a query to the server.  It therefore contains either information describing
a phrase or a URL.

**********************************************************************/


public class ResultItem {

    // There are four kinds of item
    //   1. a phrase
    //   2. a document (or URL)
    //   3. a "get more phrases" marker
    //   4. a "get more documents" marker
    // These should possibly be written as subclasses of a ResultItem
    // superclass, but I cannot be bothered rewriting it for now.

    final static int phraseItem = 1;
    final static int morePhrases = 2;
    final static int documentItem = 3;
    final static int moreDocuments = 4;

    // What kind is this item:
    int kind;

    // The "rule" is the unique identifier of this item.  For a phrase,
    // this is its "phrase number", and is also stored as a number in
    // symbol.  For a document it is the document's OID (hash) value.
    String rule;
    int symbol;

    // The term frequency of the item
    int freq;

    // The document frequency of the item
    int documents;

    // Can this item be expanded?  ---- obsolete?
    int expansion;

    // When the item is a phrase, the text of the item is split into a
    // prefix, body, and suffix.  The body is the search term and the
    // prefix and suffix the surrounding text in the new phrase.
    // When the item is a document, its title is stored in the body.
    String prefix;
    String body;
    String suffix;


    // Create a ResultItem for a phrase
    ResultItem(String r, String f, String d, 
	       String p, String b, String s) {

	kind = phraseItem;
	rule = r;
	symbol = Integer.valueOf(rule).intValue();

	freq = Integer.valueOf(f).intValue();
	documents = Integer.valueOf(d).intValue();
	expansion = 0;

	prefix = p;
	body = b;
	suffix = s;

    }


    // Create a ResultItem for a document
    ResultItem(String hash, String title, String df) {
	
	kind = documentItem;
	rule = hash;
	body = title;
	documents = Integer.valueOf(df).intValue();
	
	// not needed for a document
	symbol = 0;
	freq = 0;
	expansion = 0;
	prefix = "";
	suffix = "";
    }


    // Create an empty ResultItem of a given kind
    ResultItem(int k, String r) {

	kind = k;

	rule = r;
	symbol = -1;

	freq = 0;
	expansion = 0;
	documents = 0;

	prefix = "";
	body = "";
	suffix = "";
    }

    // Return the full phrase described by the item.
    public String toString() {
	String result = "";
	if (!prefix.equals("")) result = prefix.replace(' ', '+') + "+";
	result += body.replace(' ', '+');
	if (!suffix.equals("")) result += "+" + suffix.replace(' ', '+');
	return(result.trim());
    }

    // Is the item a phrase?
    public boolean isPhrase() {
	return (kind == phraseItem);
    }

    // Is the item a document?
    public boolean isDocument() {
	return (kind == documentItem);
    }

    public boolean isMorePhrases() {
	return (kind == morePhrases);
    }

    public boolean isMoreDocuments() {
	return (kind == moreDocuments);
    }


}


